!---------------------------------------------------------------------------------------
! GRID_TO_NCDF: initialize
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> initialize
!! 
!! Purpose:   Initialize variables 
!!
!---------------------------------------------------------------------------------------

subroutine initialize(files, config)

  use mod_var
  use mod_settings
  use mod_flexpart, only: read_header

  implicit none

  type (files_t),  intent(in out)        :: files
  type (config_t), intent(in)            :: config

  character(max_path_len)                :: filename
  logical                                :: lexist
  integer                                :: numpoint
  integer                                :: ibdate, ibtime
  integer, dimension(maxpoint)           :: releases
  real                                   :: bndx, bndy, delx, dely
  integer                                :: numx, numy
  integer                                :: i, ierr

  ! initialize flexpart variables
  ! -----------------------------

  if ( .not.config%lnested ) filename = trim(files%path_flexpart)//'header'
  if ( config%lnested )      filename = trim(files%path_flexpart)//'header_nest'
  print*, filename
  inquire(file=trim(filename),exist=lexist)
  if ( .not.lexist ) then
    print*, 'ERROR initialize: cannot find flexpart header'
    stop
  endif

  print*, 'Reading flexpart header: '//trim(filename)
  call read_header(filename, numpoint, ibdate, ibtime, releases, &
                   numx, numy, bndx, bndy, delx, dely)
  nxgrid = numx
  nygrid = numy
  llx = bndx
  lly = bndy
  dx = delx
  dy = dely

  if ( config%linversionout ) then
    ngrid = trajdays*ndgrid+2
  else
    ngrid = numpoint
    if ( .not.allocated(reltime) ) allocate( reltime(ngrid) ) 
    reltime = releases(1:ngrid)
  endif
  datei = ibdate
  timei = ibtime
  print*, 'ibdate, ibtime = ',ibdate, ibtime
  print*, 'trajdays = ',trajdays
  print*, 'ngrid = ',ngrid
  print*, 'nxshift = ',nxshift

  ! initialize lon and lat dimensions
  if ( .not.allocated(glon) ) allocate( glon(nxgrid) )
  if ( .not.allocated(glat) ) allocate( glat(nygrid) )
  do i = 1, nxgrid
    glon(i) = llx + (i-1)*dx
  end do
  do i = 1, nygrid
    glat(i) = lly + (i-1)*dy
  end do
  print*, 'initialize: glon = ',glon
  print*, 'initialize: glat = ',glat

  ! nzgrid is z dimension of grid_init files (read from header)
  ! nzlev is z dimension of grid_time files with surface only
  nzlev = 1

end subroutine initialize


